@@ -92,7 +92,7 @@ class LessonFilePreviewWidget(gtk.VBox):
                     l = gtk.Label(u"-")
                     l.set_alignment(0.0, 0.5)
                     self.g_topic_box.pack_start(l, False)
-            except (lessonfile.InfoCache.FileNotFound, 
+            except (lessonfile.InfoCache.FileNotFound,
                     lessonfile.InfoCache.FileNotLessonfile), e:
                 self.g_title.set_text(u'')
                 self.g_module.set_text(u'')
@@ -148,7 +148,7 @@ def parent_page(obj):
             return p
         if p is None:
             return None
-    
+
 class Section(gtk.VBox):
     """
     A section consists of a heading and a list of links.
@@ -763,11 +763,11 @@ class Editor(gtk.Window, gu.EditorDialogBase):
         assert self.m_model == None
         self.m_model = pd.load_tree(filename, C_locale=True)
         self.m_filename = filename
-        # 
+        #
         if not os.path.isabs(filename):
             if not os.access(filename, os.W_OK):
                 m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_INFO,
-                    gtk.BUTTONS_CLOSE, _("The default learning tree is write protected in your install. This is normal. If you want to edit a learning tree, you have to select one of the trees stored in .solfege/learningtrees in your home directory."))
+                    gtk.BUTTONS_CLOSE, _("The front page file is write protected in your install. This is normal. If you want to edit a front page file, you have to select one of the trees stored in .solfege/exercises/*/ in your home directory."))
                 m.run()
                 m.destroy()
         self.set_not_modified()
